@@ -1,6 +1,6 @@
 package Getopt::EX::Util;
 
-use strict;
+use v5.14;
 use warnings;
 
 use Exporter 'import';
